#!/bin/sh
export PATH='/usr/obj/hs-glib-0.12.5.4/bin:/usr/bin:/bin:/usr/sbin:/sbin:/usr/local/bin:/usr/local/bin:/usr/X11R6/bin'
echo 'name: glib
version: 0.12.5.4
id: glib-0.12.5.4-d17f895d256b06ee8202922370af528b

license: LGPL-2.1
copyright: (c) 2001-2010 The Gtk2Hs Team
maintainer: gtk2hs-users@lists.sourceforge.net
stability: stable
homepage: http://projects.haskell.org/gtk2hs/
package-url:
synopsis: Binding to the GLIB library for Gtk2Hs.
description: The GNU Library is a collection of C data structures and utility
             function for dealing with Unicode. This package only binds as
             much functionality as required to support the packages that
             wrap libraries that are themselves based on GLib.
category: System
author: Axel Simon, Duncan Coutts
pkgpath: devel/hs-glib
exposed: True
exposed-modules: System.Glib System.Glib.GError
                 System.Glib.Properties System.Glib.Attributes System.Glib.Signals
                 System.Glib.MainLoop System.Glib.GDateTime System.Glib.GObject
                 System.Glib.Utils System.Glib.StoreValue System.Glib.FFI
                 System.Glib.Flags System.Glib.UTFString System.Glib.Types
                 System.Glib.GList System.Glib.GString System.Glib.GType
                 System.Glib.GTypeConstants System.Glib.GValue
                 System.Glib.GValueTypes System.Glib.GParameter
hidden-modules:
trusted: False
import-dirs: /usr/local/lib/ghc/glib-0.12.5.4
library-dirs: /usr/local/lib/ghc/glib-0.12.5.4 /usr/local/lib
hs-libraries: HSglib-0.12.5.4
extra-libraries: gobject-2.0 glib-2.0 intl
extra-ghci-libraries:
include-dirs: /usr/local/include/glib-2.0
              /usr/local/lib/glib-2.0/include /usr/local/include
includes:
depends: base-4.7.0.2-e1c96ce41208f09c293083d78870d5a2
         containers-0.5.5.1-d4bd887fb97aa3a46cbadc13709b7653
         utf8-string-0.3.8-33d6cbdc649f1dd0048718c4b65b149b
hugs-options:
cc-options:
ld-options:
framework-dirs:
frameworks:
haddock-interfaces: /usr/local/share/doc/hs-glib-0.12.5.4/html/glib.haddock
haddock-html: /usr/local/share/doc/hs-glib-0.12.5.4/html
' | '/usr/local/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-db' "$@"
